@@ -28,6 +28,7 @@ class AboutData : public QObject {
   Q_PROPERTY(QString textLicense READ textLicense CONSTANT);
   Q_PROPERTY(QString transLicense READ transLicense CONSTANT);
   Q_PROPERTY(QString contributors READ contributors CONSTANT);
+  Q_PROPERTY(QString platform READ platform CONSTANT);
 
 public:
   AboutData(QObject *parent = 0);
@@ -38,6 +39,7 @@ public:
   QString textLicense() const;
   QString transLicense() const;
   QString contributors() const;
+  QString platform() const;
 };
 
 #endif /* ABOUT_DATA_H */
