@@ -113,12 +113,16 @@ int DataProvider::pageNumberForSuraAndAya(int sura, int aya) {
   return p->index;
 }
 
-QString DataProvider::partName(int page) {
+QString DataProvider::partNameForPage(int page) {
   _Page *p = &Pages[page];
 
   return QString::fromUtf8(Parts[p->part].name);
 }
 
+QString DataProvider::partName(int part) {
+  return QString::fromUtf8(Parts[part].name);
+}
+
 bool DataProvider::hasPage(int page) const {
   return page >= MIN_PAGE && page <= MAX_PAGE;
 }
@@ -320,6 +324,23 @@ int DataProvider::suraSize(int sura) {
   return Suras[sura].length;
 }
 
+
+QList<Fragment> DataProvider::fragmentsForPart(int part) {
+  QList<Fragment> frags;
+
+  for (int x = 0; x <= MAX_PAGE; x++) {
+    if (Pages[x].part == part) {
+      frags += pageFromIndex(x).fragments();
+    }
+    else if (!frags.isEmpty()) {
+      // We filled our list already
+      break;
+    }
+  }
+
+  return frags;
+}
+
 int Fragment::sura() const {
   return Fragments[m_index].sura;
 }
