@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011 Mohammed Sameer <msameer@foolab.org>. All rights reserved.
+ * Copyright (c) 2011-2012 Mohammed Sameer <msameer@foolab.org>.
  *
  * This package is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 #define SETTINGS_H
 
 #include <QObject>
-#include <QColor>
 #include <QPoint>
 
 class QSettings;
@@ -38,10 +37,7 @@ class Settings : public QObject {
   Q_PROPERTY(int minTranslationFontSize READ minTranslationFontSize CONSTANT);
   Q_PROPERTY(int maxTranslationFontSize READ maxTranslationFontSize CONSTANT);
   Q_PROPERTY(int translationFontSize READ translationFontSize WRITE setTranslationFontSize NOTIFY translationFontSizeChanged);
-  Q_PROPERTY(QColor highlightColor READ highlightColor CONSTANT);
-  Q_PROPERTY(QColor verseColor READ verseColor CONSTANT);
-  Q_PROPERTY(QColor titleColor READ titleColor CONSTANT);
-  Q_PROPERTY(QColor subtitleColor READ subtitleColor CONSTANT);
+
   Q_PROPERTY(QString version READ version CONSTANT);
   Q_PROPERTY(bool fontLoaded READ isFontLoaded CONSTANT);
   Q_PROPERTY(bool fullScreen READ fullScreen WRITE setFullScreen NOTIFY fullScreenChanged);
@@ -55,6 +51,10 @@ class Settings : public QObject {
 
   Q_PROPERTY(int recitationMode READ recitationMode WRITE setRecitationMode NOTIFY recitationModeChanged);
   Q_PROPERTY(QString defaultRecitation READ defaultRecitation WRITE setDefaultRecitation NOTIFY defaultRecitationChanged);
+  Q_PROPERTY(bool flipToStopRecitation READ flipToStopRecitation WRITE setFlipToStopRecitation NOTIFY flipToStopRecitationChanged);
+
+  Q_PROPERTY(bool nightMode READ isNightModeEnabled WRITE setNightModeEnabled NOTIFY nightModeChanged);
+  Q_PROPERTY(QString theme READ theme WRITE setTheme NOTIFY themeChanged);
 
 public:
   Settings(QObject *parent = 0);
@@ -82,11 +82,6 @@ public:
   void setBookmarks(const QList<uint>& bookmarks);
   QList<uint> bookmarks() const;
 
-  QColor highlightColor() const;
-  QColor verseColor() const;
-  QColor titleColor() const;
-  QColor subtitleColor() const;
-
   QString version() const;
 
   void loadFont();
@@ -117,6 +112,15 @@ public:
   void setDefaultRecitation(const QString& id);
   QString defaultRecitation() const;
 
+  void setFlipToStopRecitation(bool enabled);
+  bool flipToStopRecitation();
+
+  void setNightModeEnabled(bool enabled);
+  bool isNightModeEnabled();
+
+  void setTheme(const QString& theme);
+  QString theme();
+
 public slots:
   void reset();
 
@@ -140,6 +144,9 @@ signals:
   void centerTextChanged();
   void recitationModeChanged();
   void defaultRecitationChanged();
+  void flipToStopRecitationChanged();
+  void nightModeChanged();
+  void themeChanged();
 
 private:
   QSettings *m_settings;
