@@ -3,11 +3,6 @@
 
 #include <QObject>
 
-namespace ResourcePolicy {
-  class ResourceSet;
-  class AudioResource;
-};
-
 class AudioPolicy : public QObject {
   Q_OBJECT
 
@@ -21,10 +16,6 @@ signals:
   void acquired();
   void lost();
   void denied();
-
-private:
-  ResourcePolicy::ResourceSet *m_set;
-  ResourcePolicy::AudioResource *m_audio;
 };
 
 #endif /* AUDIO_POLICY_H */
